0.10.21 UPD 28 sie Windows, Linux

Pobierz Team Red Miner

TeamRedMiner — pełny przewodnik

Opcje:

  -a, --algo=ALGORITHM      Wybiera algorytm kopania.  Obecnie dostępne:
                              ethash            (eth, etp i inne)
                              etchash           (etc, alias dla -a ethash --eth_variant_mode=etchash)
                              kawpow            (ravencoin)
                              firopow           (firo)
                              mtp_firopow       (wybiera firopow lub mtp i wyłącza minera przy forku 26 października 2021)
                              autolykos2        (ergo)
                              verthash          (vtc)
                              ton               (ton)
                              kas               (kaspa)
                              nimiq             (nimiq)
                              lyra2z
                              phi2              (lux, argoneum)
                              lyra2rev3
                              x16r
                              x16rv2
                              x16s              (pgn, xsh)
                              x16rt             (gin)
                              mtp               (zcoin/firo przed forkiem firopow)
                              cuckatoo31_grin   (grin)
                              cuckarood29_grin  (grin)
                              cnv8
                              cnr               (stare monero)
                              cnv8_half         (stellite, masari)
                              cnv8_dbl          (x-cash)
                              cnv8_rwz          (graft)
                              cnv8_trtl         (stare turtlecoin, loki)
                              cnv8_upx2         (uplexa)
                              cn_heavy          (klasyczny CN heavy)
                              cn_haven          (haven)
                              cn_saber          (bittube)
                              cn_conceal        (conceal)
                              trtl_chukwa       (turtlecoin)
                              trtl_chukwa2      (turtlecoin)

  -h, --help                Wyświetla tę pomoc i kończy działanie.
      --debug               Włącza dziennik debugowania.
      --hardware=HW_LIST    Określa, na jakich typach sprzętu miner ma próbować działać, w postaci listy rozdzielonej przecinkami.
                              Obecnie obsługiwane wartości to 'gpu' i 'fpga'.  Na przykład:
                                --hardware=gpu,fpga
      --benchmark           Włącza tryb benchmarku.  Wszystkie zdefiniowane pule są ignorowane, a automatycznie dodawana jest jedna
                              wewnętrzna sztuczna pula.  Aby testować algorytmy takie jak eth i kawpow dla konkretnych epok i wysokości
                              bloków, musisz też dodać argumenty specyficzne dla algorytmu, np. --eth_epoch=456 i --prog_height=123456.
      --disable_colors      Wyłącza kolory w konsoli.
      --force_colors        Wymusza kolory w konsoli, nawet jeśli terminal wydaje się ich nie obsługiwać.
      --api_listen=IP:PORT  Włącza API zgodne z sgminer. IP:PORT jest opcjonalne. Jeśli podano, para IP:PORT
                              określa interfejs(y) i port nasłuchu. Domyślnie 127.0.0.1:4028. Dla
                              dostępu z zewnątrz użyj np. 0.0.0.0:4028. Można też podać tylko
                              port, np. 4029.  Można teraz podać ten argument wiele razy dla osobnych endpointów.
      --api2_listen=IP:PORT Włącza drugi port API dla konfiguracji podwójnego kopania.  Ten endpoint API podaje dane
                              drugiego algorytmu, tak jakby równolegle działały dwie osobne instancje minera.
                              Domyślnie 127.0.0.1:4029, czyli port 4029, a nie 4028.  Aby podać własną wartość,
                              użyj tego samego formatu co dla --api_listen.  Można teraz podać ten argument
                               wiele razy dla osobnych endpointów.
      --cm_api_listen=IP:PORT Włącza API zgodne z Claymore. IP:PORT jest opcjonalne. Jeśli podano, para IP:PORT
                              określa interfejs(y) i port nasłuchu. Domyślnie 127.0.0.1:3333. Dla
                              dostępu z zewnątrz użyj np. 0.0.0.0:3333. Można też podać tylko
                              port, np. 3334.
      --cm_api_password=PSW Ustawia hasło wymagane przez interfejs API zgodny z CM.
      --log_file(=FILENAME) Włącza zapis wyjścia minera do pliku FILENAME.  Jeśli nie podano nazwy pliku,
                              miner zapisuje dziennik do trm_<algo>_<yyyymmdd_hhmmss>.log w bieżącym
                              katalogu roboczym.  Jeśli plik dziennika już istnieje, miner dopisuje do niego.
  -l, --log_interval=SEC    Ustawia interwał w sekundach uśredniania i wyświetlania hashrate kart.
                              SEC to interwał w sekundach i musi być > 0.
      --log_rotate=SZ[,CNT] Włącza rotację dzienników. Wartość SZ ustawia rozmiar dziennika, po którym tworzony jest
                              nowy plik.  SZ obsługuje sufiksy 'k', 'M' i 'G', które mnożą wartość
                              odpowiednio przez 1024, 1048576 i 1073741824. Opcjonalna wartość CNT ustawia
                              maksymalną liczbę przechowywanych starych plików dziennika.  Na przykład opcja '--log_rotate=4M,16'
                              sprawi, że miner przełączy się na nowy plik dziennika, gdy bieżący przekroczy
                              4194304 bajtów, i będzie przechowywał 16 ostatnich takich plików, usuwając
                              starsze.
      --short_stats         Wyłącza pełny stan kart w każdym wyjściu hashrate, jak przed wersją 0.7.10.
      --dev_location=LOC    Wybiera konkretną lokalizację dla połączenia opłaty dewelopera. Używaj tylko, jeśli miner
                              stale zgłasza problemy z połączeniem opłaty dewelopera. Zarządzanie połączeniem
                              zwykle działa dobrze we wszystkich lokalizacjach. Dostępne opcje:
                              world     - Cały świat z wyjątkiem Chin kontynentalnych.
                              non-gcp   - Kraje z zablokowanym dostępem do usług Google (np. Iran, Kuba).
                              cn        - Chiny kontynentalne.
                              eu        - UE, Rosja, Ukraina i okolice.
                              us        - USA, Kanada, Ameryka Środkowa/Południowa.
                              asia      - Azja bez Chin.
      --enable_compute      (Tylko Windows) Włącza tryb compute i wyłącza crossfire na kartach, które tego wymagają.
      --long_timestamps     Włącza w dziennikach znaczniki czasu z mikrosekundami zamiast samych sekund.
      --restart_gpus        (Tylko Windows) Restartuje wszystkie skonfigurowane karty przed kopaniem, tj. wyłącza+włącza urządzenie PCI.
      --uac                 (Tylko Windows) Włącza podniesienie uprawnień, gdy miner wykonuje zadania takie jak restart kart.
                              Zawsze możesz tego uniknąć, uruchamiając minera bezpośrednio jako administrator.  Spowoduje to
                              wyświetlenie standardowego okna podniesienia uprawnień Windows, więc musisz być obecny, aby kliknąć 'Tak'.
                              Jeśli ta opcja nie jest włączona, zadania wymagające uprawnień administratora nie powiodą się, gdy
                              miner działa na zwykłym koncie użytkownika.
      --high_score          Włącza wyświetlanie w statystykach 15 najlepszych udziałów znalezionych od startu minera.
                              Uwaga: może nie być dostępne dla wszystkich algorytmów.
      --allow_dup_bus_ids   Pozwala wielu kartom używać tego samego identyfikatora magistrali pci.  Używaj tylko dla kart Radeon Pro Duo
                              i podobnego sprzętu; zwykle oznacza to uszkodzone środowisko OpenCL.
      --dns_https=URL       Włącza rozwiązywanie nazw DNS pul przez DNS-over-HTTPS.  To funkcja eksperymentalna.  TRM obsługuje
                              tylko wariant oparty na JSON, a nie mechanizm zdefiniowany później w RFC8484.  Użytkownik musi
                              podać pełny adres https wraz z nazwą metody.  Można podawać nazwy hostów
                              zamiast surowych adresów IP, ale takie nazwy będą rozwiązywane przez systemowy DNS.
                              Oto kilka przykładów, które zostały sprawdzone i działają:

                              --dns_https=https://8.8.8.8/resolve           (Google DNS)
                              --dns_https=https://9.9.9.9:5053/dns-query    (Quad9)
                              --dns_https=https://1.1.1.1/dns-query         (usługa DNS Cloudflare)
      --dns_https_sni=HOST  Przy użyciu argumentu --dns_https domyślnie w połączeniu SSL/TLS nie jest wysyłany
                              SNI.  Ten argument pozwala wymusić wysyłanie dowolnego SNI.  Pamiętaj,
                              że to zaawansowany argument sieciowy i większość użytkowników go nie potrzebuje.
      --kernel_vm_mode=X    (Tylko Linux). Automatyzuje ustawianie potrzebnych parametrów jądra w /etc/default/grub w systemach Linux
                              opartych na Debian/Ubuntu.  Obejmuje to większość dystrybucji do kopania.  System może zostać
                              automatycznie zrestartowany przez /sbin/reboot po zmianie parametrów jądra.  Jeśli właściwe
                              parametry są już ustawione, miner i skrypt pomocniczy nic nie zrobią. Oznacza to, że
                              ten argument może zawsze być obecny w wierszu poleceń.  Dopuszczalne wartości:
                                N  -  brak trybu, usuwa istniejące parametry trybu C lub R.  Bez restartu po zmianie.
                                C  -  stary tryb C dla Radeon VII.  Bez restartu po zmianie.
                                R  -  nowy tryb R dla wszystkich kart oprócz Polaris.  Bez restartu po zmianie.
                                RN -  brak trybu, usuwa istniejące parametry trybu C lub R.  Restart po zmianie.
                                RC -  stary tryb C dla Radeon VII.  Restart po zmianie.
                                RR -  nowy tryb R dla wszystkich kart oprócz Polaris.  Restart po zmianie.
      --kernel_vm_mode_script=X  (Tylko Linux).  Określa skrypt wywoływany do ustawienia nowych parametrów trybu jądra.
                              Skrypt musi działać jak domyślny skrypt TRM dołączony do paczki minera,
                              ubuntu_mode_script.sh.  Zwykle ten argument nie jest potrzebny.
      --gpu_sdma=on|off     Określa, czy sterownik używa bezpośrednich operacji sdma do kopiowania pamięci do/z
                              karty. Ten argument jest potrzebny tylko w bardzo szczególnych sytuacjach. Na przykład AMD BC-250
                              nie obsługuje sdma i wymaga --gpu_sdma=off. Jeśli miner zawiesza się od razu przy inicjalizacji
                              karty, a inne minery lub starsze wersje TRM działają dobrze, spróbuj --gpu_sdma=off.
                              To ustawienie środowiskowe i dotyczy wszystkich kart.

Opcje konfiguracji puli:

  -o, --url=URL             Ustawia adres URL puli.  Obecnie obsługiwane są adresy stratum+tcp i stratum+ssl.
                              Każde kolejne podanie tej opcji rozpoczyna nową konfigurację puli.
                              Opcje dla poszczególnych pul (takie jak -u, -p) trzeba jawnie podać
                              ponownie dla każdej nowej puli.  (Zobacz przykładowy plik start_multipool.sh/bat)
                              Strategię wielu pul ustawia się opcją --pool_strategy.
                              Jest też specjalna obsługa zaawansowanych konfiguracji SSL/TLS, w których trzeba
                              przekazać nazwę hosta SNI do endpointu SSL. Jest to potrzebne np. dla endpointów SSL,
                              które działają jako frontendy wielu hostów i muszą wiedzieć, dla którego
                              udostępnić certyfikat. W takich przypadkach użyj formatu:
                              -o stratum+ssl://pool.tunnel.com/pool.realhostname.com:3333
                              Spowoduje to połączenie z pool.tunnel.com:3333, ale przekazanie pool.realhostname.com jako nazwy
                              hosta SNI w fazie handshake SSL. Obie nazwy hostów mogą też być oczywiście identyczne.
  -u, --user=USERNAME       Ustawia nazwę użytkownika do autoryzacji w puli.
  -p, --pass=PASSWORD       Ustawia hasło do autoryzacji w puli.
      --pool_force_ensub    Wymusza żądanie extranonce subscribe dla obsługujących je pul nieznanych minerowi.
      --pool_no_ensub       Blokuje wysyłanie przez minera żądania extranonce subscribe do puli.
      --pool_broken_rpc     Pozwala minerowi na tylko jedno oczekujące żądanie rpc w połączeniu
                              z pulą.  To obejście dla pul, które naruszają specyfikację json rpc
                              w zakresie identyfikatorów rpc.
      --pool_ratio=RATIO    Ustawia proporcję hashrate między pulami przy korzystaniu z wielu pul ze strategiami
                              'load_balance' lub 'quota' (zob. --pool_strategy).  Domyślnie wszystkie
                              pule mają proporcję 1.  Na przykład użycie tej opcji z wartością 2
                              tylko dla jednej puli sprawi, że dostanie ona dwa razy większy hashrate niż pozostałe pule,
                              bo ich proporcja wciąż będzie miała domyślną wartość 1.
      --pool_debug          Zapisuje w dzienniku cały ruch z pulą.

Globalne opcje puli:

      --pool_connect_TO=SEC Ustawia limit czasu próby połączenia z pulą. SEC to czas oczekiwania w
                              sekundach. Domyślnie 10.
      --pool_rpc_TO=SEC     Ustawia, jak długo miner czeka na odpowiedź na RPC do puli.  Po tym
                              czasie miner ponownie łączy się z pulą.  SEC to czas oczekiwania w sekundach.
                              Domyślnie 60.
      --pool_max_rejects=N  Jeśli pula odrzuci N udziałów z rzędu, połączenie z pulą jest resetowane. Chroni to
                              przed pulami, które unieważniają sesje kopania bez rozłączania użytkownika.
                              Wartość domyślna to 5.
      --pool_share_limit_ms=N  Jeśli pula potrzebuje więcej niż N ms na przyjęcie lub odrzucenie udziału, bieżące
                              połączenie zostaje zerwane i nawiązane ponownie.  Przeznaczone dla pul, które często mają problemy
                              z niektórymi serwerami; ponowne połączenie oznacza przekierowanie na inny i
                              miejmy nadzieję lepszy serwer.  Domyślnie bez limitu czasu.
      --pool_strategy=STRAT Ustawia strategię wyboru pul przy pracy z wieloma pulami.  Dostępne
                              wartości: priority, load_balance, quota i min_epoch.  Domyślnie priority.
                              priority: miner używa pul w kolejności, w jakiej są wymienione, przechodząc
                                do następnej puli tylko wtedy, gdy z poprzednią nie da się nawiązać połączenia.
                              load_balance: miner równomiernie rozkłada hashrate na wszystkie aktualnie
                                połączone pule.  Proporcję hashrate między pulami można ustawić przez --pool_ratio.
                              quota: miner równomiernie rozkłada łączną liczbę obliczonych hashy na
                                wszystkie pule.  Jeśli pula się rozłączy, a potem połączy ponownie, miner przeniesie
                                na nią hashrate, aż łączna liczba hashy dla każdej puli się wyrówna.
                                Proporcję hashrate między pulami można ustawić przez --pool_ratio.
                              min_epoch: strategia przełączania ETH + ZIL.  Miner zawsze kopie najniższą epokę
                                spośród wszystkich połączonych pul, a przy remisie — pierwszą połączoną pulę.
                                Dlatego podaj pulę ETH jako pierwszą/główną pulę, a pulę ZIL
                                jako drugą.  Dla tej strategii możesz też użyć nazwy 'eth_zil'.
      --no_ntime_roll       Blokuje zmienianie przez minera ntime w nagłówku bloku; używana jest tylko wartość
                              podana przez pulę. Przy kopaniu x16rt trzeba to włączyć dla niektórych pul.
      --no_stale_submit     Blokuje wysyłanie udziałów, które nie dotyczą najnowszego zadania puli.

Opcje GPU:

      --platform=INDEX      Ustawia indeks używanej platformy OpenCL. Jeśli nie podano, platforma zostanie
                              wykryta automatycznie. Linux z wieloma platformami jest obsługiwany tylko bez argumentu
                              --platform, ale z dodanym --bus_reorder.
  -d, --devices=DEVLIST     Ustawia karty z wykrytej listy, które mają być używane. DEVLIST to lista indeksów urządzeń
                              rozdzielona przecinkami, np. -d 0,1,2,4.  Jeśli nie podano, używane są wszystkie
                              urządzenia na platformie(-ach).  UWAGA: domyślnie urządzenia są uporządkowane
                              według kolejności magistrali pcie. Użyj --list_devices, aby wyświetlić indeksy.
      --init_style=1/2/3    Określa styl inicjalizacji (domyślnie 1):
                              1: jedna karta naraz, wszystkie inicjalizowane przed kopaniem.
                              2: trzy karty naraz, wszystkie inicjalizowane przed kopaniem.
                              3: wszystkie karty równolegle, kopanie zaczyna się od razu.
      --pcie_fmt=FORMAT     Ustawia format wyświetlania numerów magistrali pcie.  Akceptowane wartości FORMAT to
                              'hex' lub 'dec'.  Domyślnie dec dla windows i hex dla linux.
      --bus_reorder         Porządkuje wykryte lub podane urządzenia według identyfikatora magistrali pcie.  Jeśli nie
                              podano platformy, urządzenia są zbierane ze wszystkich wykrytych platform AMD OpenCL.
                              Uwaga: od wersji v0.7.0 jest to zachowanie domyślne.
      --opencl_order        Porządkuje wykryte lub podane urządzenia w kolejności, w jakiej przedstawia je OpenCL.
      --list_devices        Wyświetla dostępne urządzenia dla wykrytej lub podanej platformy i natychmiast
                              kończy działanie.  Zmiana kolejności magistrali zostanie uwzględniona w wyświetlanej kolejności.
      --nr_cu_override=X,Y,... Nadpisuje liczbę jednostek obliczeniowych na kartę podawaną przez API OpenCL. Przydaje się
                              głównie dla Vega 64 z wgranym biosem 56, gdy sterownik
                              podaje 56 CU zamiast rzeczywistej liczby.  Jako wartość argumentu podaj listę
                              nadpisanych liczb CU dla każdej karty, rozdzieloną przecinkami.  Możesz pomijać karty i nie
                              musisz podawać wartości dla wszystkich kart w rigu.  Przykład dla mieszanego riga z dwiema kartami Vega
                              o indeksach 1 i 3 oraz dwiema innymi kartami: --nr_cu_override=,64,,64.  Możesz sprawdzić swój
                              argument, dodając też --list_devices przed kopaniem.

Opcje sterowania taktowaniem/napięciem (tylko windows, funkcja BETA):

                              Miner ma podstawowe funkcje ustawiania taktowania rdzenia i pamięci oraz ich
                              napięć, a także wyboru między wbudowanymi timingami sterownika windows.  Dla każdego
                              dostępnego argumentu poniżej podajesz wartości dla kart w rigu w postaci listy
                              rozdzielonej przecinkami.  Niektóre argumenty nie są używane dla pewnych kart.  Karty na liście można pomijać.
                              Na kartach GCN (Polaris, Vega) miner zawsze ustawia i używa najwyższego p-state zarówno dla rdzenia,
                              jak i pamięci.  Pamiętaj, że karty Rx Vega _muszą_ mieć zmodyfikowaną tabelę powerplay
                              dla stanu p2 pamięci, zanim będą mogły pracować z napięciem niższym niż 900mV.  Ponadto karty Big Navi
                              nadal wymagają np. MorePowerTool do modyfikacji tabeli powerplay, na przykład
                              aby umożliwić ustawienie niższego napięcia.  Miner _być może_ w przyszłości doda obsługę funkcji
                              związanych z tabelą powerplay.
      --clk_debug                 Włącza wyświetlanie przy starcie informacji o ustawianiu taktowań/napięć/timingów.
      --clk_core_mhz=MHZ1,MHZ2,... Ustawia taktowanie rdzenia każdej karty w MHz.
      --clk_core_mv=MV1,MV2,...    Ustawia napięcie rdzenia każdej karty w mV.
      --clk_mem_mhz=MHZ1,MHZ2,...  Ustawia taktowanie pamięci każdej karty w MHz.
      --clk_mem_mv=MV1,MV2,...     Ustawia napięcie pamięci każdej karty w mV.  Nieużywane dla kart Navi i Big Navi.
      --clk_timing=V1,V2,...       Wybiera jeden z dostępnych w sterowniku zestawów timingów pamięci.  Niedostępne na wszystkich kartach i
                                   sterownikach.
                              Przykład części wiersza poleceń dla systemu z czterema kartami: Rx Vega 64, 580, 5700XT i
                              6800, kopiącego ethash lub podobny.   Napięcie pamięci podajemy tylko dla Vegi i 580, a wartość
                              timingów sterownika wybieramy tylko dla Big Navi:
                              teamredminer.exe ... --clk_core_mhz=1100,1000,1275,1000 --clk_core_mv=875,850,725,675
                              --clk_mem_mhz=1107,2100,1820,2130 --clk_mem_mv=875,850,, --clk_timing=,,,1

Opcje sterowania wentylatorami:

      --fan_control(=CFG1,CFG2,...)  Ten argument włącza sterowanie wentylatorami kart przez minera.  TRM obsługuje
                              automatyczne dostosowanie prędkości wentylatorów na podstawie temperatury rdzenia, złącza (junction) i/lub pamięci.
                              Obsługujemy też ustawienie stałej prędkości wentylatora w procentach.
                              Każdy typ karty ma konfigurację wentylatora używaną domyślnie.  Obsługujemy
                              zarówno nadpisanie domyślnej konfiguracji dla typu karty, jak i ustawienie
                              osobnej konfiguracji dla każdej karty w rigu.
                              Konfiguracja wentylatora składa się z (maks.) sześciu wartości rozdzielonych znakiem ':' (dwukropek).  Wartości
                              to: docelowa temperatura rdzenia, docelowa temperatura złącza, docelowa temperatura pamięci, początkowa prędkość
                              wentylatora w procentach, minimalna prędkość w procentach, maksymalna prędkość w procentach.  Każdą wartość można pominąć.
                              Kilka przykładów:
                              ::70:50:25   Docelowa temperatura pamięci 70C, start wentylatora na 50%, minimalna prędkość 25%.
                              55::::20:80  Docelowa temperatura rdzenia 55C, start wentylatora na prędkości z konfiguracji domyślnej,
                                           wentylator zawsze między 20% a 80%.
                              55::75:80    Dostosowuje wentylator tak, by temperatura rdzenia była <= 55C, a pamięci <= 75C, start
                                           wentylatora na 80%.
                              :::100       Stała prędkość wentylatora 100%, bez dostosowywania do temperatur.
                              Konfiguracja wentylatora dla karty jest ustalana według następującej kolejności pierwszeństwa:
                              1. Do argumentu --fan_control przekazano listę konfiguracji zawierającą
                                 wpis dla karty X.
                              2. Domyślna konfiguracja wentylatora dla tego typu karty została nadpisana parametrem
                                 --fan_default_<type>=... .
                              3. Używana jest wbudowana domyślna konfiguracja wentylatora dla tego typu karty.
                              Jeśli w wybranej konfiguracji z listy powyżej brakuje wartości startowej wentylatora,
                              używane jest ustawienie z następnej konfiguracji.
                              UWAGA: obsługa wentylatorów to funkcja beta i nie zadziała lepiej niż obsługa, którą
                              zapewniają sterowniki.  Na przykład sterowniki w linuksie często nie pozwalają wymusić
                              wentylatora na 100% przez obsługę pwm w sysfs.
      --fan_default_polaris=CFG Ustawia domyślną konfigurację dla wszystkich kart Polaris (450/460/550/560/470/480/570/580/590).
                              Wbudowana wartość domyślna to 55:::50, czyli temperatura rdzenia 55C i start wentylatora na 50%.
                              Uwaga: to ustawienie jest używane także dla kart Tonga.
      --fan_default_vega=CFG    Ustawia domyślną konfigurację dla wszystkich kart Vega (Vega 56/Vega 64).
                              Wbudowana wartość domyślna to 55::70:50, czyli rdzeń 55C, pamięć 70C i wentylator na 50%.
      --fan_default_vega2=CFG   Ustawia domyślną konfigurację dla wszystkich kart Radeon VII.
                              Wbudowana wartość domyślna to 70::75:80, czyli rdzeń 70C, pamięć 75C i wentylator na 80%.
      --fan_default_navi=CFG    Ustawia domyślną konfigurację dla wszystkich kart Navi (Navi10).
                              Wbudowana wartość domyślna to 60::80:70, czyli rdzeń 60C, pamięć 80C i wentylator na 70%.
      --fan_default_big_navi=CFG  Ustawia domyślną konfigurację dla wszystkich kart Big Navi (Navi21).
                              Wbudowana wartość domyślna to 50:::70, czyli rdzeń 50C i wentylator na 70%. Temperatura
                              pamięci nie jest uwzględniona z powodu braku czujnika w bibliotece Windows ADL.
      --fan_debug             Włącza wyświetlanie w dzienniku informacji o zmianach.
      --fan_no_restore        Wyłącza przywracanie oryginalnych profili wentylatorów przy zamykaniu minera.

Opcje watchdoga:

      --no_gpu_monitor      Wyłącza monitor GPU ADL (Windows) lub sysfs (Linux) dla temperatury i
                              prędkości wentylatora.
      --temp_limit=TEMP     Ustawia temperaturę rdzenia, przy której miner zatrzyma zbyt gorące karty.
                              Domyślnie 85C.  Wartości dla poszczególnych kart można podać listą rozdzieloną przecinkami,
                              po jednej wartości na kartę.  Jeśli karta nie ma zdefiniowanej wartości, używana jest pierwsza wartość z listy.
      --temp_resume=TEMP    Ustawia temperaturę rdzenia, poniżej której miner wznowi karty wcześniej
                              zatrzymane z powodu przekroczenia limitu temperatury rdzenia.  Domyślnie 60C.  Wartości dla poszczególnych
                              kart można podać listą rozdzieloną przecinkami, po jednej wartości na kartę.  Jeśli karta nie
                              ma zdefiniowanej wartości, używana jest pierwsza wartość z listy.
      --mem_temp_limit=TEMP Ustawia temperaturę pamięci, przy której miner zatrzyma zbyt gorące karty.
                              Domyślnie wyłączone.  Używane tylko, jeśli karta ma czujnik temperatury pamięci.
                              Wartości dla poszczególnych kart można podać listą rozdzieloną przecinkami, po jednej wartości na kartę.
                              Jeśli karta nie ma zdefiniowanej wartości, używana jest pierwsza wartość z listy.
      --mem_temp_resume=TEMP Ustawia temperaturę pamięci, poniżej której miner wznowi karty wcześniej
                              zatrzymane z powodu przekroczenia limitu temperatury pamięci.  Domyślnie wyłączone.  Używane
                              tylko, jeśli karta ma czujnik temperatury pamięci.  Wartości dla poszczególnych kart można podać
                              listą rozdzieloną przecinkami, po jednej wartości na kartę.  Jeśli karta nie ma zdefiniowanej wartości,
                              używana jest pierwsza wartość z listy.
      --watchdog_script(=X) Konfiguruje watchdog kart tak, by wyłączał minera, uruchamiał podany skrypt
                              i natychmiast kończył działanie. Domyślny skrypt to watchdog.bat/watchdog.sh w
                              bieżącym katalogu, ale jako opcjonalny argument można podać inny skrypt,
                              także ze ścieżką bezwzględną lub względną.
      --watchdog_test       Testuje skonfigurowany skrypt watchdoga, wywołując to samo działanie co przy martwej karcie
                              po ~20 s kopania.
      --watchdog_disabled   Wymusza niewykonywanie watchdoga. Pozwala wyłączyć watchdog w systemach do kopania,
                              które zawsze uruchamiają minera z włączonym watchdogiem.

Opcje Ethash:

      --eth_config=CONFIG   Ręczna konfiguracja ethash dla minera.  CONFIG musi mieć postać [X][M][L].
                              Wartość [M] wybiera tryb: 'A', 'B' lub 'C'.
                              Tryb 'B' używa dodatkowej pamięci i działa tylko na kartach 8+GB.
                              Tryb 'C' używa dodatkowej pamięci i działa tylko na kartach 16+GB, takich jak VII, przy
                              poprawnie skonfigurowanym systemie.  Więcej szczegółów w ETHASH_TUNING_GUIDE.txt.
                              Wartość [L] wybiera intensywność, a jej zakres zależy od architektury GPU.
                              Prefiks [X] jest opcjonalny i dotyczy tylko Navi/Big Navi; włącza więcej operacji na pamięci i
                              prowadzi do niższej wartości strojenia [L]. Może się przydać, gdy autostrojenie wielokrotnie
                              trafia w wartość bliską maksymalnej możliwej dla karty.
                              Obie wartości są opcjonalne, ale jeśli podano [L], trzeba też podać [M].
                              Przykładowe konfiguracje: --eth_config=A
                                               --eth_config=B750
                                               --eth_config=XB
                              CONFIG może też być listą wartości rozdzieloną przecinkami, z których każda jest
                              stosowana do kolejnej karty. Na przykład: --eth_config=A,B750,,A288
                              Każda karta bez własnej konfiguracji na liście użyje pierwszej
                              konfiguracji z listy.
      --eth_variant_mode=X  Ten argument steruje włączaniem zmian ethash dla ETC od epoki 390 opisanych
                              w ecip-1099. Dostępne są następujące tryby:
                              pool      - Tryb domyślny. Włącza się tylko, jeśli pula wyśle flagę algorytmu zawierającą etchash.
                                          Po zobaczeniu tej flagi wszystkie zadania puli są traktowane jako etchash, dopóki nie
                                          przyjdzie inna flaga algorytmu zawierająca ethash.
                              etchash   - Tryb etchash. Epoka >= 390 jest traktowana jako etchash, niższe epoki jako ethash. Flagi
                                          algorytmu z puli nie są używane.
                              deduce    - Ignoruje flagi algorytmu z puli i stosuje tylko heurystykę opartą na bieżącym czasie systemowym
                                          oraz znanych wysokościach i czasach dla ETC i ETH. Ten tryb powinien działać jako ogólne
                                          rozwiązanie, gdy ETH osiągnie epokę 390 w styczniu 2021. Zegar systemowy musi być poprawny.
                                          Powinien też obsłużyć konfiguracje profit switching, które swobodnie przełączają się między zadaniami
                                          ethash i etchash, pośrednicząc w dostępie do pul.
                              auto      - Dopóki pula nie przekazała flagi algorytmu, używa trybu deduce. Po zobaczeniu flagi algorytmu
                                          przełącza się na tryb pool.
                              ethash    - Wymuszony tryb ethash. Nigdy nie stosuje ecip-1099.
                              force_etc - Wymuszony tryb etchash. Zawsze stosuje reguły ecip-1099. Do kopania w sieci testowej ETC.
      --eth_aggr_mode       Włącza automatyczne użycie trybu 'B' dla wszystkich kart Polaris 8GB, chyba że mają
                              inną konfigurację podaną argumentem --eth_config.  To to samo co
                              ręczne ustawienie wszystkich kart Polaris 8GB w rigu w tryb 'B' przez --eth_config.
                              Na większości kart dodaje to 0.1-0.2 MH/s hashrate.  UWAGA: 20-25% rigów działa mniej
                              stabilnie w tym trybie, dlatego nie jest on domyślny.  Jeśli karty zaczną
                              padać, usuń ten argument i uruchom karty w trybie 'A'.
      --eth_stratum_mode=MODE Ustawia stały tryb stratum dla pul ethash.  Domyślnie miner próbuje
                              automatycznie ustalić typ stratum obsługiwany przez pulę i używa tego trybu.
                              To automatyczne wykrywanie można nadpisać tą opcją.  MODE może przyjąć
                              jedną z wartości: stratum, nicehash, ethproxy.
      --eth_worker          Ustawia identyfikator workera wysyłany do puli.  Dotyczy tylko pul w trybie stratum
                              ethproxy.
      --eth_hash_report=X   Steruje raportami hashrate wysyłanymi do skonfigurowanych pul.  Wartość dotyczy wszystkich pul. Wartości:
                              default   - miner decyduje na podstawie protokołu stratum używanego przez każdą pulę.
                              force     - zawsze wysyła raporty hashrate, nawet jeśli pula je odrzuca.
                              on        - wysyła pierwszy raport hashrate i wyłącza raporty dla każdej puli, która go odrzuci.
                              off       - nigdy nie wysyła raportów hashrate.
      --eth_epoch           Testuje konkretną epokę ethash. UWAGA: automatycznie przełącza minera w tryb benchmarku, tak
                              jakby dodano --benchmark.
      --eth_alloc_epoch=N   Od startu alokuje pamięć wystarczającą dla podanej epoki.  Jeśli później podczas kopania będzie
                              potrzeba więcej, miner spróbuje zaalokować więcej.
      --eth_dag_buf=X,Y,... Miner może alokować jeden lub dwa bufory na DAG.  Obecnie domyślnie AUTO.  Pojedynczy
                              bufor jest nieco lepszy i daje niewielką oszczędność energii na wszystkich typach kart.  Tylko nowsze sterowniki obsługują
                              pojedyncze alokacje większe niż 4GiB, zwykle od Adrenalin 20.9.1 i amdgpu-pro 20.x. Miner
                              może automatycznie używać trybu pojedynczego bufora, gdy to możliwe, a ten argument pozwala też wymusić pojedynczy lub podwójny
                              bufor dla każdej karty.  Obsługiwane wartości to A(uto), S(ingle), D(ual).  Możesz podać listę rozdzieloną przecinkami
                              dla wszystkich kart w rigu albo jedną wartość dla wszystkich kart.  Karta bez wartości na
                              liście rozdzielonej przecinkami użyje pierwszej wartości.
      --eth_big_mode_adjust=X,Y,...  W trybach B i C miner działa tym lepiej, im więcej vram może zaalokować.  Niestety
                              sterowniki niedokładnie podają, ile pamięci można zaalokować, zwłaszcza w Windows.
                              Miner używa bezpiecznego, zachowawczego odstępu 256MiB (Linux) i 512MiB (Windows) od
                              dostępnego rozmiaru vram.  Jeśli chcesz zmienić tę liczbę, możesz to zrobić tym argumentem, podając
                              listę rozdzieloną przecinkami z wartościami dla jednej lub kilku kart.  Wartości dla kart, które nie działają w trybie B/C, są
                              ignorowane.  Jeśli karta nie ma wartości na liście, używana jest pierwsza podana wartość.
                              Dozwolony zakres to [-64, 2048]. Im wyższa liczba, tym mniej vram jest alokowane na karcie.
      --eth_dag_slowdown=N  Spowalnia generowanie DAG.  Podaj jedną cyfrę 0-9. 0 oznacza brak spowolnienia (zachowanie <= 0.7.9),
                              1 minimalne spowolnienie, 9 maksymalne.  Wartość domyślna: 4, czyli lekkie spowolnienie.
      --eth_stagger         Włącza rozkładanie w czasie startu kart przy budowie nowego DAG.  Mniej obciąża zasilacze, które nie lubią
                              skoku z 0 do 100% obciążenia na wszystkich kartach jednocześnie.
      --eth_no_stagger      Wyłącza --eth_stagger.  Od 0.7.18 to już zachowanie domyślne.  Argument zachowano tylko dla
                              zgodności wstecznej.
      --eth_ramp_up         Dodaje stopniowe zwiększanie intensywności na wszystkich kartach po budowie DAG, wyłączeniu/włączeniu karty lub awarii sieci.
                              Może pomóc rigom, które wysypują się tuż między budową DAG a rozpoczęciem kopania.
      --eth_no_ramp_up      Wyłącza --eth_ramp_up.  Od 0.7.18 to już zachowanie domyślne.  Argument zachowano tylko dla
                              zgodności wstecznej.
      --eth_direct_abort    Używa innego mechanizmu przerywania trwających zadań na karcie.  Zalecane dla kart Vega w środowiskach ROCm,
                              aby zminimalizować nieaktualne udziały.  Dotyczy tylko kart Vega i Polaris w rigu.
      --eth_dag_alloc_patch Na niektórych płytach głównych z nieaktualnym biosem mogą występować błędy sprzętowe, zwykle na pierwszej lub ostatniej karcie w systemie.
                              Ten argument wymusza poprawioną strategię alokacji dag, która najczęściej rozwiązuje problem.
                              Aktualizacja biosu też często go rozwiązuje.
      --eth_hashwatch(=M,M) Określa minimalny/maksymalny hashrate watchdoga w MH/s oczekiwany podczas haszowania przez karty.  Jeśli karta
                              zbyt długo jest poza tym zakresem, zostanie uznana za wadliwą i zostanie wywołany watchdog.  Domyślne
                              wartości min/maks to 2 MH/s i 150 MH/s.  Aby włączyć z wartościami domyślnymi, użyj
                              --eth_hashwatch.  Aby ustawić własne wartości, użyj np. --eth_hashwatch=1.25,60.  Ten sam zakres dotyczy
                              wszystkich kart w rigu.  Wartość ujemna dla jednej strony ją wyłącza, np. użyj --eth_hashwatch=-1,1000,
                              aby obsłużyć resety kart dające ogromny fałszywy hashrate, bez sprawdzania minimum.
      --eth_dag_cache(=EPOCH) Włącza zapisywanie DAG eth z zadań o różnych epokach, aby nie trzeba ich było przebudowywać w
                              przyszłości, jeśli znów przyjdą zadania ze starymi epokami.  Jeśli pozwala na to pamięć karty, zapisywany jest
                              maksymalnie jeden DAG.  Przydaje się przy przełączaniu pul, np. przy kopaniu eth+zil.  Jeśli chcesz od razu przy starcie
                              zbudować określoną epokę, dodaj opcjonalną wartość. Minery przełączające eth+zil powinny używać
                              --eth_dag_cache=0.  Obecnie wstępnie budować można tylko epoki ethash (nie etchash).
      --eth_dag_cache_resv=MEM  Ustawia ilość pamięci karty, którą miner będzie starał się zostawić wolną przy włączonym buforowaniu
                              DAG (zob. --eth_dag_cache).  Argument MEM to ilość pamięci do pozostawienia wolnej w
                              mebibajtach.  Wartość domyślna to 256.
      --eth_dag_cache_verify    Włącza odczyt i weryfikację bufora dag po zakończeniu budowy dag.  Wykrywa to sytuacje,
                              w których bufor dag miał błędy bitowe i wynikowy dag jest częściowo uszkodzony.  Widzieliśmy, że
                              zdarza się to coraz częściej na kartach Vega w miarę wzrostu dag.  Po wykryciu alokowany jest nowy bufor
                              dla bufora dag, a budowa dag zaczyna się od nowa.
      --eth_micro_delay=VAL,VAL,...  Dodaje opóźnienie (w mikrosekundach) przy ponownym kolejkowaniu pracy na karcie/kartach.
                              Słabsze zasilacze obsługujące wiele kart czasem nie radzą sobie z „szybkością narastania”, gdy kilka kart
                              ponownie kolejkuje pracę dokładnie w tym samym momencie.  Ustawienie np. 32 wystarczająco wygładza przejście
                              od braku obciążenia do 100% obciążenia, by zmniejszyć szybkość narastania na takich rigach.  Typowym objawem tego
                              problemu są twarde zawieszenia, po których rig przestaje odpowiadać i wymaga odłączenia zasilania, ale mogą to być też
                              zwykłe awarie kart.  Dopuszczalne wartości to 0-256.  Wartości dla poszczególnych kart można podać listą rozdzieloną przecinkami.
                              Karty bez wartości na liście użyją pierwszej wartości. Domyślne wartości tego argumentu przy
                              kopaniu samego ethash:
                                Polaris: 64
                                Vega:    0
                                Navi:    0
      --eth_ignore_abort_fail   Nieudane przerwanie zadania zwykle wynika ze zbyt wysokiej intensywności, dlatego miner
                              automatycznie ją obniża.  Ta opcja _wyłącza_ tę logikę: intensywność pozostaje, a
                              zamiast tego w dzienniku pojawia się ostrzeżenie.
      --eth_no_job_logs         Wyłącza wszystkie wpisy dziennika o nowych zadaniach otrzymanych z puli/pul.  Dotyczy wszystkich sesji kopania z rodziny ethash,
                              tj. w konfiguracji podwójnej eth+zil wyciszone zostaną wpisy dla obu pul eth i zil.  Zadania puli,
                              które przechodzą na nową epokę, nadal będą zapisywane.
      --eth_smooth_power=X,Y,...  Harmonogramowanie „smooth power” dodano w 0.10.0 i jest dostępne dla wszystkich typów kart.
                              To zasadniczo dobra funkcja, która dodaje odrobinę hashrate i w większości przypadków poprawia stabilność,
                              dlatego jest domyślnie włączona na wszystkich kartach.  Są jednak rigi, które źle na nią reagują i
                              zaczynają się wysypywać.  Wtedy możesz tym argumentem sterować funkcją dla każdej karty w rigu.
                              Dopuszczalne wartości to 0 lub 1. Dla riga z 5 kartami możesz użyć --eth_smooth_power=0,1,1,1,0, aby wyłączyć smooth
                              power na pierwszej i ostatniej karcie.  Jeśli nie podasz wartości dla karty, używana jest pierwsza wartość z listy.
                              Oznacza to, że możesz wyłączyć funkcję dla całego riga przez --eth_smooth_power=0.

Opcje Progpow (kawpow, firopow):

      --prog_config=CONFIG  Ręczna konfiguracja progpow dla minera.  CONFIG musi mieć postać [M][L].
                              Wartość [M] wybiera tryb: 'A' lub 'B'.
                              Tryb 'B' zwykle daje lepszą wydajność, ale jest dostępny tylko dla
                              Vega w linuksie i Navi (linux lub windows).
                              Wartość [L] wybiera intensywność, a jej zakres zależy od architektury GPU.
                              Obie wartości są opcjonalne, ale jeśli podano [L], trzeba też podać [M].
                              Przykładowe konfiguracje: --prog_config=A
                                               --prog_config=B750
                              CONFIG może też być listą wartości rozdzieloną przecinkami, z których każda jest
                              stosowana do kolejnej karty. Na przykład: --prog_config=A,B750,,A288
                              Każda karta bez własnej konfiguracji na liście użyje pierwszej.
      --prog_height=VALUE   Ustawia stałą wysokość bloku dla algorytmów progpow na potrzeby benchmarku.  Automatycznie
                              przełącza minera w tryb benchmarku.
      --prog_strict         Wymusza, by miner zawsze generował ściśle dokładne kernele.  Domyślnie miner
                              generuje uproszczone kernele, które zużywają mniej mocy obliczeniowej, ale mogą powodować
                              sporadyczne nieważne udziały.
      --prog_dag_slowdown=N  Spowalnia generowanie DAG.  Podaj jedną cyfrę 0-9.  0 oznacza brak spowolnienia (zachowanie <= 0.7.9),
                              1 minimalne spowolnienie, 9 maksymalne.  Wartość domyślna: 4, czyli lekkie spowolnienie.
      --prog_stagger         Zob. --eth_stagger.
      --prog_ramp_up         Zob. --eth_ramp_up.
      --prog_no_stagger      Zob. --eth_no_stagger.
      --prog_no_ramp_up      Zob. --eth_no_ramp_up.
      --prog_micro_tune=X,Y,... Ta opcja włącza krótką sesję ponownego dostrajania dla każdego nowego losowego bloku kodu.  Jest to ważne,
                               aby karty Polaris pracowały z maksymalną prędkością.  Dla Vega i Navi zwykle nie poprawia to
                               wydajności.  Domyślny tryb AUTO włącza ją dla wszystkich kart Polaris, a w pozostałych przypadkach wyłącza.
                               Jedynym powodem do jej wyłączenia byłaby stabilność.  Wartością argumentu jest
                               lista wartości rozdzielona przecinkami, po jednej na kartę.  Jeśli dla karty brakuje wartości, używana jest wartość
                               pierwszej karty.  Pamiętaj, że ręczne ustawienie prog_config w praktyce także wyłącza
                               mikrostrojenie.  Dostępne wartości:
                               1 - WYŁĄCZA mikrostrojenie progpow dla tej karty.
                               2 - WŁĄCZA mikrostrojenie progpow dla tej karty.
                               3 - miner sam decyduje, czy włączyć mikrostrojenie (AUTO).
      --prog_hash_report    Włącza wymuszone raporty hashrate (jak dla ethash) wysyłane do wszystkich pul.  To alias dla
                               --eth_hash_report=force, który również ma zastosowanie, bo progpow i ethash używają tych samych
                               protokołów puli.

Opcje Cryptonight:

      --rig_id              Ustawia identyfikator riga wysyłany do puli. Używane tylko dla
                              pul cryptonight.
      --cn_config=CONFIG    Ręczna konfiguracja cryptonight dla minera.  CONFIG musi mieć postać
                              [P][I0][M][I1][:xyz], gdzie [P] to opcjonalny prefiks, a [:xyz] to
                              opcjonalny sufiks.  Dla [P] obsługiwana jest tylko wartość 'L' dla słabszych
                              kart, takich jak Lexa/Baffin.  [I0] i [I1] to wartości intensywności wątków, zwykle
                              od 1 do 16, ale dla kart 16GB możliwe są większe wartości.  [M] to
                              tryb, który może być '.', '-', '+' lub '*'.  Tryb '.' oznacza, że miner
                              ma sam wybrać lub wyszukać najlepszy tryb.  Tryb '*' to dobry tryb domyślny i
                              _powinien_ być używany, jeśli kopiesz na Vega 56/64 ze zmodyfikowanymi timingami pamięci.
                              Wyjątkiem od tej reguły są warianty z małym scratchpadem (cnv8_trtl i cnv8_upx2), które
                              nadal powinny używać '+'. Dla kart Polaris dostępne są tylko tryby '-' i '+'.

                              UWAGA: w TRM 0.5.0 dodano autostrojenie, przez co ręczna konfiguracja
                              trybów CN jest zbędna poza rzadkimi przypadkami brzegowymi.  Więcej informacji
                              znajdziesz w dokumentacji strojenia i poradnikach dołączonych do wydania.

                              Przykładowe konfiguracje: --cn_config=15*15:AAA
                                               --cn_config=14-14
                                               --cn_config=L4+3
                              CONFIG może też być listą wartości rozdzieloną przecinkami, z których każda jest
                              stosowana do kolejnej karty. Na przykład: --cn_config=8-8,16+14:CBB,15*15,14-14
                              Każda karta bez własnej konfiguracji na liście użyje pierwszej
                              konfiguracji z listy.
      --no_cpu_check        Wyłącza weryfikację znalezionych udziałów na cpu przed wysłaniem ich do puli.
                              Uwaga: obecnie weryfikację na cpu obsługują tylko algorytmy CN.
      --no_lean             Wyłącza tryb lean CN, w którym wątki są stopniowo uruchamiane przy starcie lub restarcie po
                              problemach z siecią albo dławieniu z powodu temperatury karty.
      --no_interleave=DEVS  Wymienia karty, na których nie należy używać logiki przeplatania wątków CN.
                              Argument to lista urządzeń rozdzielona przecinkami, jak dla opcji -d.
                              Użyj tego argumentu, jeśli niektóre urządzenia mają gorszy hashrate i jednocześnie dużo
                              komunikatów interleave adjust w dzienniku.
      --alloc_patch=DEVS    Wymienia karty, które tracą hashrate między TRM v0.4.5 a późniejszymi wersjami. Z tym
                              argumentem używana jest prostsza strategia alokacji pamięci, co powinno przywrócić dawny (wyższy)
                              hashrate. Nadal można korzystać z trybu autostrojenia.
      --auto_tune=MODE      Włącza tryb autostrojenia przy starcie. Dostępne tylko dla wariantów CN. MODE musi
                              mieć wartość NONE, QUICK lub SCAN. Tryb QUICK sprawdza kilka znanych dobrych konfiguracji
                              i kończy się w ciągu 1 min. Tryb SCAN sprawdza wszystkie możliwe kombinacje i
                              trwa 20-30 min. Ustawienie MODE na NONE wyłącza autostrojenie. Domyślny
                              tryb to QUICK.
      --auto_tune_runs(=N)  Wykonuje wiele przebiegów autostrojenia, za każdym razem zmniejszając liczbę używanych scratchpadów o 1
                              w jednym z wątków (15+15 -> 15+14 -> 14+14 -> 14+13 -> ...). Możesz podać
                              konkretną liczbę przebiegów albo pozwolić minerowi wybrać wartość domyślną dla typu karty (zwykle 3-4).
      --auto_tune_exit      Jeśli podano, miner zakończy działanie po zakończeniu autostrojenia. Przydaje się,
                              gdy chcesz wyszukać optymalne ustawienia, a potem użyć wynikowego argumentu wiersza poleceń
                              wyświetlonego przez minera.
      --allow_large_alloc   Jeśli podano, a sterownik wskazuje, że karta ma wystarczająco dużo vram, miner
                              będzie bardziej agresywny przy początkowej alokacji pamięci. W praktyce ta opcja
                              oznacza, że karty Vega w Linuksie zaczną autostrojenie od 16*15 zamiast
                              16*14 lub 15*15.

Opcje MTP:

      --allow_all_devices   Niektórych algorytmów nie da się kopać np. na kartach 4GB. Takie karty miner
                              wyłącza automatycznie. Ten argument nadpisuje tę logikę i pozwala kopać na wszystkich podanych
                              lub wykrytych urządzeniach.

Opcje X16*:

      --hash_order=VALUE    Ustawia stałą kolejność hashy dla algorytmów takich jak x16r na potrzeby benchmarku.
                              To ustawienie automatycznie przełącza minera w tryb benchmarku.
                              Standardowa kolejność hashy w benchmarku dla x16r to --hash_order=0123456789abcdef.

Opcje Nimiq:

      --nimiq_worker=VALUE  Ustawia nazwę workera/urządzenia dla nimiq przekazywaną do puli/pul.
      --nimiq_no_proxy      Wyłącza automatyczne proxy Nimiq uruchamiane jako osobny proces. Oznacza to, że
                              host i port przekazane minerowi muszą wskazywać na proxy.
      --nimiq_proxy=VALUE   Nadpisuje domyślną ścieżkę do proxy Nimiq. Domyślnie to trm_nimiq_proxy-win.exe
                              i trm_nimiq_proxy-linux w bieżącym katalogu minera.
      --nimiq_port=VALUE    Nadpisuje domyślny lokalny port (4444) używany przez proxy Nimiq. Przydaje się, jeśli
                              w systemie port 4444 jest już używany przez inną usługę tcp/ip.

Opcje Verthash:

      --verthash_file=FILE  Ustawia nazwę pliku używanego do wczytywania/zapisywania pliku danych verthash.  Jeśli ta opcja
                              jest podana przy algorytmie verthash, miner spróbuje wczytać dane verthash
                              z pliku.  Jeśli plik nie istnieje, miner wygeneruje dane verthash
                              i zapisze je w pliku do przyszłego użytku.  Jeśli ta opcja nie jest podana,
                              miner przy każdym starcie generuje dane verthash w pamięci systemowej.
      --verthash_max_uploads=N  Na niektórych płytach głównych pojawiają się problemy, gdy wszystkie karty w rigu jednocześnie
                              wgrywają tabelę verthash.  Ten argument ogranicza liczbę kart, które przy starcie
                              jednocześnie wgrywają tabelę.  Dozwolone wartości to 1-32.  Wartość domyślna to 4.

Opcje Autolykos2:

      --autolykos_mem_adjust=N  Ustawia ilość pamięci w MiB, którą miner ma zostawić wolną przy alokacji
                              buforów GPU dla autolykos.  Wartość domyślna to 384 w linuksie i 512 w windows.  Dla kart
                              z podłączonymi monitorami wartość domyślna jest zwiększana o 512.  Przy podwójnym kopaniu z ZIL
                              wartość domyślna jest zwiększana o 1024.  Opcję można też podać jako listę wartości rozdzieloną
                              przecinkami, z których każda dotyczy kolejnej karty.  Jeśli na liście podano pustą wartość,
                              dla tej karty zostanie użyta wartość domyślna.  Jeśli dla karty nie podano wartości,
                              użyje ona pierwszej wartości z listy.  Używana ilość vram musi pomieścić zarówno główne
                              bufory, jak i ewentualny bufor wstępnie budowany dla następnej wysokości.  Na przykład:
                                    --autolykos_mem_adjust=256,512,,256
      --autolykos_prebuild=N  Ustawia szybkość wstępnego budowania pad dla następnej wysokości.  Wyższa wartość oznacza szybsze budowanie,
                              ale z większymi wahaniami poboru mocy i prawdopodobnie większym spadkiem hashrate, dopóki trwa
                              budowanie.  Dopuszczalne wartości to 0-9, gdzie 0 oznacza brak wstępnego budowania, a 9 to wariant najszybszy.
                              Wartość domyślna to 3 lub 4, zależnie od karty.  Możesz podać jedną wartość dla wszystkich
                              kart albo listę wartości dla każdej karty rozdzieloną przecinkami.
      --autolykos_slowdown=N  Spowalnia proces budowania pad.  Dopuszczalne wartości to 0-100. Domyślnie 0, czyli bez
                              spowolnienia.
      --autolykos_ignore_diff Ignoruje trudność wysyłaną przez pulę i używa tylko 256-bitowego celu podanego w zadaniach.
                              Niektóre pule nie trzymają się referencyjnej implementacji puli dla minera ERGO; wtedy ten
                              argument _może_ pomóc. UWAGA: dotyczy wszystkich pul.

Opcje podwójnego kopania ZIL:

      --zil_start or --zil  Rozpoczyna konfigurację podwójnego kopania ZIL.  Wszystkie argumenty między nim a znacznikiem --zil_end
                              dotyczą kopania ZIL, a nie głównego algorytmu.  Zakłada się, że główny algorytm
                              został skonfigurowany we wcześniejszych argumentach.  Chodzi o to, by można było dodać konfigurację
                              --zil ... --zil_end do dowolnej działającej konfiguracji TRM i wszystko od razu działało.
                              Ten argument automatycznie ustawia szereg domyślnych ustawień przydatnych dla ZIL:
                               - Kopia DAG ZIL dla epoki 0 w buforze.
                               - Dostosowanie pamięci alokowanej dla głównego algorytmu, aby zmieścił się DAG ZIL.
                               - Wybór trybu A ethash dla kopania ZIL.
                              Minimalna działająca konfiguracja to podanie tylko puli ZIL, która akceptuje to, że miner ignoruje
                              zadania głównej monety i kopie tylko w oknach ZIL.  Przykład dla ezil.me:
                              --zil -o stratum+tcp://eu.ezil.me:5555 -u <eth wallet>.<zil wallet>.<worker name> -p x --zil_end
                              Więcej informacji w przewodniku po podwójnym kopaniu ZIL dołączonym do wydania TRM.
      --zil_end             Oznacza koniec konfiguracji kopania ZIL; wszystkie kolejne argumenty dotyczą głównego
                              algorytmu.  Ten argument nie jest bezwzględnie konieczny, ale warto go dodać w dystrybucjach do kopania, bo
                              użytkownik nie ma gwarancji, jakie argumenty dystrybucja automatycznie dopisze na końcu wiersza
                              poleceń.
      --stats_mode=single/dual  Po dodaniu podwójnego kopania ZIL wyjście statystyk jest domyślnie zdublowane, aby pokazać informacje
                              o kopaniu ZIL.  Może to zmylić narzędzia, które parsują wyjście TRM lub
                              pliki dziennika.  Aby przełączyć się na standardowe wyjście, dodaj --stats_mode=single.

Opcje TON:

      --ton_pool_mode=X     Określa używany dialekt kopania TON.  Jeśli nie ustawiono, miner spróbuje ustalić właściwy wybór
                              na podstawie nazwy hosta puli.  Dostępne opcje:
                              toncoinpool - używa protokołu stratum wss dla toncoinpool.
                              icemining   - używa protokołu stratum ice mining przez tcp/ip.
                              tonpool     - używa wersji protokołu stratum ice mining od tonpool przez wss.
      --wss_force_proxy     Wymusza włączenie automatycznego proxy wss uruchamianego jako osobny proces dla pul TON, które prowadzą
                              protokół kopania przez wss.  Miner zwykle włącza je automatycznie, ale jeśli do połączenia używany jest surowy adres IP
                              lub alias nazwy hosta, ten argument może być potrzebny.
      --wss_no_proxy        Wyłącza automatyczne proxy wss uruchamiane jako osobny proces dla pul TON, które prowadzą
                              protokół kopania przez wss. Oznacza to, że host i port przekazane minerowi muszą wskazywać
                              na proxy.
      --wss_proxy=VALUE     Nadpisuje domyślną ścieżkę do proxy wss. Domyślnie to trm_nimiq_proxy-win.exe
                              i trm_nimiq_proxy-linux w bieżącym katalogu minera, bo pierwotnie było ono używane tylko dla
                              Nimiq.
      --wss_port=VALUE      Nadpisuje domyślny lokalny port (4444) używany przez proxy wss. Przydaje się, jeśli
                              w systemie port 4444 jest już używany przez inną usługę tcp/ip.

Opcje podwójnego kopania Ethash:

      --ton_start or --ton  Rozpoczyna konfigurację podwójnego kopania TON.  Wszystkie argumenty między nim a znacznikiem --ton_end
                              dotyczą kopania TON, a nie głównego algorytmu, zwykle ethash.  Zakłada się, że
                              ethash został skonfigurowany we wcześniejszych argumentach.  Chodzi o to, by można było dodać konfigurację
                              --ton ... --ton_end do dowolnej działającej konfiguracji TRM i wszystko od razu działało.
                              Minimalna działająca konfiguracja to podanie tylko puli TON.  Informacje o obsługiwanych pulach
                              znajdziesz w przewodniku po kopaniu TON. Przykład dla icemining z adresem jego puli beta:
                              --ton -o stratum+tcp://ton.hashrate.to:4003 -u <ton wallet>.<worker name> -p x --ton_end
                              Więcej informacji w przewodniku po podwójnym kopaniu TON dołączonym do wydania TRM.
      --ton_end             Oznacza koniec konfiguracji kopania TON; wszystkie kolejne argumenty dotyczą głównego
                              algorytmu.  Ten argument nie jest bezwzględnie konieczny, ale warto go dodać w dystrybucjach do kopania, bo
                              użytkownik nie ma gwarancji, jakie argumenty dystrybucja automatycznie dopisze na końcu wiersza
                              poleceń.
      --kas_start or --kas  Rozpoczyna konfigurację podwójnego kopania Kaspa.  Wszystkie argumenty między nim a znacznikiem --kas_end
                              dotyczą kopania Kaspa, a nie głównego algorytmu, zwykle ethash.  Zakłada się, że
                              ethash został skonfigurowany we wcześniejszych argumentach.  Chodzi o to, by można było dodać konfigurację
                              --kas ... --kas_end do dowolnej działającej konfiguracji TRM i wszystko od razu działało.
                              Minimalna działająca konfiguracja to podanie tylko puli Kaspa.  Przykład:
                              --kas -o stratum+tcp://pool.woolypooly.com:3112 -u <kaspa wallet>.<worker name> -p x --kas_end
      --kas_end             Oznacza koniec konfiguracji kopania Kaspa; wszystkie kolejne argumenty dotyczą głównego
                              algorytmu.  Ten argument nie jest bezwzględnie konieczny, ale warto go dodać w dystrybucjach do kopania, bo
                              użytkownik nie ma gwarancji, jakie argumenty dystrybucja automatycznie dopisze na końcu wiersza
                              poleceń.
      --dual_intensity=X,Y,Z,... Ten argument dostosowuje intensywność podwójnego kopania współczynnikiem od 0.0 do 1.0, gdzie 1.0
                              oznacza możliwie największy udział drugiego algorytmu.  Opcja jest zalecana do obniżenia poboru mocy
                              bez obniżania taktowania rdzenia, co wpłynęłoby również na hashrate ethash.

                              Argument podaje się jako jedną globalną wartość albo listę wartości dla każdej karty.  Przykłady:

                                --dual_intensity=0.75            Wszystkie karty używają 75% maksymalnej możliwej dostępności GPU dla TON.
                                --dual_intensity=0.75,1.0,0.5    Osobne wartości dla trzech pierwszych kart w rigu, pozostałe karty
                                                                 używają pierwszej wartości, czyli 75%.

      --dual_tuner_step=X   Ustawia krok, którego tuner podwójnego kopania używa przy sprawdzaniu różnych intensywności konfiguracji eth.  Niższa
                              wartość daje dokładniejsze wyniki, ale trwa dłużej.  Dopuszczalne wartości to 1,2,4,8,16,32,64.
      --dual_tuner_period=X Ustawia liczbę sekund, przez które tuner podwójnego kopania testuje każdą sprawdzaną konfigurację.  Domyślnie 7 s.
      --dual_tuner_weights=X:Y:Z  Tuner podwójnego kopania potrzebuje wag punktowych określających, ile jest wart 1 MH/s głównego i drugiego
                              algorytmu.  W minerze są wbudowane wartości domyślne, aktualne w chwili implementacji
                              i dodania każdego algorytmu, ale wraz ze zmianami hashrate sieci i cen rynkowych może być potrzebne podanie nowych wartości.
                              Ten argument przyjmuje trzy wartości, wszystkie powinny być liczbami dodatnimi:
                                X    Punkty za 1 MH/s głównego algorytmu (zwykle ethash).
                                Y    Punkty za 1 MH/s drugiego algorytmu (zwykle TON lub Kaspa).
                                Z    Koszt 1 W zmierzonej mocy. Na razie zalecamy ustawienie zera.
                              Przykład dla ETH+TON:
                                Na podstawie ręcznej wartości względnej: każdy MH/s ETH jest wart 100 MH/s TON/Kaspa
                                --dual_tuner_weights=100:1:0
                                Na podstawie kalkulatorów kopania: $0.0437 za 1 MH/s ETH, $0.0005476 za 1 MH/s TON/Kaspa
                                --dual_tuner_weights=0.0437:0.0005476:0

Opcje FPGA:

      --fpga_devices=LIST   Ustawia urządzenia FPGA z wykrytej listy, które mają być używane. LIST to lista rozdzielona przecinkami zawierająca
                              indeksy urządzeń lub ich DNA, tak jak pokazuje je --list_devices.
                                Przykłady:  -d 0,1,2,4
                                            -d 40020000013ae32135111111,40020000013ae32135222222,40020000013ae32135333333
                              Jeśli nie podano, używane są wszystkie dostępne urządzenia FPGA.
      --fpga_clk_core=LIST  Ustawia taktowanie rdzenia urządzeń FPGA.  Taktowania podaje się jako
                              listę wartości w megahercach rozdzieloną przecinkami, gdzie każda wartość dotyczy kolejnego urządzenia FPGA.
                              Jeśli lista jest krótsza niż liczba urządzeń, pozostałe urządzenia użyją
                              pierwszej wartości z listy.  Na przykład --fpga_clk_core=600,620 ustawi 600MHz na
                              FPGA 0 i 620MHz na FGPA 1.  Jeśli są urządzenia FPGA 2+, zostaną ustawione na 600MHz.
      --fpga_clk_mem=LIST   Ustawia taktowanie pamięci urządzeń FPGA.  Format taki sam jak dla --fpga_clk_core.
      --fpga_vcc_int=LIST   Ustawia napięcie vcc_int na płytkach, które to obsługują.  Wartości napięcia podaje się jako
                              listę wartości w miliwoltach (mV) rozdzieloną przecinkami, gdzie każda wartość dotyczy kolejnej płytki.
                              Jeśli lista jest krótsza niż liczba urządzeń, pozostałe urządzenia użyją
                              pierwszej wartości z listy.  Na przykład --fpga_vcc_int=700,800 ustawi vcc_int 700mV na
                              FPGA 0 i 800mV na FGPA 1.  Jeśli są urządzenia FPGA 2+, zostaną ustawione na 700mV.
      --fpga_vcc_bram=LIST  Ustawia napięcie vcc_bram na płytkach, które to obsługują.  Format taki sam jak dla --fpga_vcc_int.
      --fpga_vcc_mem=LIST   Ustawia napięcie pamięci/HBM na płytkach, które to obsługują.  Format taki sam jak dla --fpga_vcc_int.
      --fpga_update_fw      Włącza aktualizację firmware kontrolera satelitarnego dla płytek C1100 z własnym firmware TRM,
                              aby obsługiwać funkcje takie jak sterowanie napięciem w trakcie pracy. Aktualizowane są tylko płytki wybrane opcją
                              --fpga_devices, które nie mają najnowszej wersji firmware.
                              ***** UWAGA: nie przerywaj procesu aktualizacji firmware!                               *****
                              *****   Przerwanie może uszkodzić płytkę w sposób bardzo trudny do odwrócenia.          *****
      --fpga_allow_unsafe=LIST Wyłącza domyślne limity bezpieczeństwa dla podanych FPGA.  Urządzenia podaje się jako
                              listę wartości DNA rozdzieloną przecinkami, np. --fpga_allow_unsafe=40020000013ae32135111111
                              ***** UWAGA: praca powyżej limitów bezpieczeństwa może TRWALE USZKODZIĆ urządzenie!     *****
      --fpga_tcore_limit=LIST Ustawia miękkie limity temperatury rdzenia urządzeń FPGA.  Jeśli temperatura rdzenia FPGA przekroczy
                              podaną wartość, miner obniży taktowanie FPGA, aby sprowadzić temperaturę rdzenia poniżej
                              tej wartości.  Wartości w stopniach Celsjusza, w formacie listy podobnym do --fpga_clk_core.
      --fpga_tmem_limit=LIST Ustawia miękkie limity temperatury pamięci urządzeń FPGA.  Opis przy --fpga_tcore_limits.
      --fpga_ivccint_limit=LIST Ustawia miękkie limity prądu regulatora napięcia VCCINT.  Opis przy --fpga_tcore_limits.
      --fpga_ivccbram_limit=LIST Ustawia miękkie limity prądu regulatora napięcia VCCBRAM.  Opis przy --fpga_tcore_limits.
      --fpga_max_jtag_mhz=XY.Z  Ustawia maksymalną dozwoloną częstotliwość komunikacji jtag z fpga.  Domyślnie 30.0 MHz.
      --fpga_eth_clk_dag=LIST Ustawia taktowanie rdzenia FPGA używane podczas budowy DAG Ethash. Domyślnie
                              wynosi ono 90% zwykłego taktowania rdzenia. Format taki sam jak dla --fpga_clk_core.

Pobierz Team Red Miner

0.10.21